@@ -31,7 +31,10 @@ def load_dataset(path_data_file: str,
     """
 
     _idxf = numpy.atleast_1d(idx_feat)
-    data = numpy.array(pandas.read_excel(path_data_file))
+    data_file = pandas.read_excel(path_data_file)
+    data = numpy.array(data_file)
+    names_feats = data_file.columns.values[_idxf].tolist()
+    name_target = None if idx_target is None else data_file.columns.values[idx_target]
     iter_range = range(0, data.shape[0])
     list_data = list()
 
@@ -46,4 +49,8 @@ def load_dataset(path_data_file: str,
         else:
             list_data.append(Data(x=feat_vec, y=data[i, idx_target], idx=i, dtype=DTYPE_FVEC))
 
-    return Dataset(list_data, idx_feat=idx_feat, idx_target=idx_target)
+    return Dataset(list_data,
+                   idx_feat=idx_feat,
+                   idx_target=idx_target,
+                   names_feats=names_feats,
+                   name_target=name_target)
