@@ -142,7 +142,10 @@ def load_dataset(path_data_file: str,
     :return: (*Dataset*) A dataset object.
     """
 
-    data = numpy.array(pandas.read_excel(path_data_file))
+    data_file = pandas.read_excel(path_data_file)
+    data = numpy.array(data_file)
+    names_feats = [data_file.columns.values[idx_smiles]]
+    name_target = None if idx_target is None else data_file.columns.values[idx_target]
     iter_range = range(0, data.shape[0])
     list_data = list()
 
@@ -161,4 +164,9 @@ def load_dataset(path_data_file: str,
         else:
             list_data.append(Data(x=mol_graph, y=data[i, idx_target], idx=i, dtype=DTYPE_MSTRUCT))
 
-    return Dataset(list_data, idx_smiles=idx_smiles, idx_target=idx_target, add_h=add_h)
+    return Dataset(list_data,
+                   idx_smiles=idx_smiles,
+                   idx_target=idx_target,
+                   names_feats=names_feats,
+                   name_target=name_target,
+                   add_h=add_h)
